@@ -1,23 +1,34 @@
 /*
  *
- *   BaseZ
+ *  basez.h
  *
  *   Copyright (C) 2013, 2016  Milan Kupcevic
+ *   All rights reserved.
  *
- *   You can redistribute and/or modify this software under the
- *   terms of the GNU General Public License version 3, or any later
- *   version as published by the Free Software Foundation.
+ *  Redistribution and use in source and binary forms, with or without
+ *  modification, are permitted provided that the following conditions are met:
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *  1. Redistributions of source code must retain the above copyright notice,
+ *  this list of conditions and the following disclaimer.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- *   GPLv3+
+ *  2. Redistributions in binary form must reproduce the above copyright notice,
+ *  this list of conditions and the following disclaimer in the documentation
+ *  and/or other materials provided with the distribution.
  *
+ *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ *  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ *  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ *  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ *  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ *  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ *  POSSIBILITY OF SUCH DAMAGE.
+ */
+
+/*
  *
  *   Encodings per RFC 4648:
  *    base64     Base 64 Encoding
@@ -31,14 +42,12 @@
 #ifndef BASEZ_H
 #define BASEZ_H
 
-#include <stddef.h>
-
-void
+void  /* upper case encode */
 encode_base16u (
   const unsigned char  *byte_in,
   unsigned char *buffer_out);      /* 2 bytes */
 
-void
+void  /* lower case encode */
 encode_base16l (
   const unsigned char  *byte_in,
   unsigned char *buffer_out);      /* 2 bytes */
@@ -48,13 +57,13 @@ decode_base16(
   const unsigned char *buffer_in,  /* 2 bytes        */
   unsigned char *buffer_out);      /* a decoded byte */
 
-void
+void  /* upper case encode */
 encode_base32u(
   const unsigned char *buffer_in,  /* 5 bytes       */
   const int bytes_to_encode,       /* >= 1 and <= 5 */
   unsigned char *buffer_out);      /* 8 bytes       */
 
-void
+void  /* lower case encode */
 encode_base32l(
   const unsigned char *buffer_in,  /* 5 bytes       */
   const int bytes_to_encode,       /* >= 1 and <= 5 */
@@ -65,13 +74,13 @@ decode_base32(
   const unsigned char *buffer_in,  /* 8 bytes       */
   unsigned char *buffer_out);      /* 5 bytes       */
 
-void
+void  /* upper case encode */
 encode_base32hexu(
   const unsigned char *buffer_in,  /* 5 bytes       */
   const int bytes_to_encode,       /* >= 1 and <= 5 */
   unsigned char *buffer_out);      /* 8 bytes       */
 
-void
+void /* lower case encode */
 encode_base32hexl(
   const unsigned char *buffer_in,  /* 5 bytes       */
   const int bytes_to_encode,       /* >= 1 and <= 5 */
